@@ -20,13 +20,13 @@ class CLIError(Exception):
 # python3 -m ase.cli.completion to update autocompletion.
 commands_ = [
 
-    ('bgefvk', 'featurebox.cli.bgefvk'),
-    ('bader', 'featurebox.cli.bader'),
-    ('dbcvk', 'featurebox.cli.dbcvk'),
-    ('batchrun', 'featurebox.cli.batchrun'),
-    ('autoincar', 'featurebox.cli.autoincar'),
-    ('nebmake', 'featurebox.cli.nebmake'),
-    # ('run', 'ase.cli.run'),
+    ('bandgap', 'featurebox.cli.vasp_bgp'),
+    ('bader', 'featurebox.cli.vasp_bader'),
+    ('dbc', 'featurebox.cli.vasp_dbc'),
+    ('cohp', 'featurebox.cli.vasp_cohp'),
+    ('dos', 'featurebox.cli.vasp_dos'),
+    ('general', 'featurebox.cli.vasp_general_single'),
+    ('diff', 'featurebox.cli.vasp_general_diff'),
 
 ]
 
@@ -114,20 +114,23 @@ class Formatter(argparse.HelpFormatter):
         out = ''
         blocks = text.split('\n\n')
         for block in blocks:
-            if block[0] == '*':
-                # List items:
-                for item in block[2:].split('\n* '):
-                    out += textwrap.fill(item,
-                                         width=width - 2,
-                                         initial_indent='* ',
-                                         subsequent_indent='  ') + '\n'
-            elif block[0] == ' ':
-                # Indented literal block:
-                out += block + '\n'
+            if block != "":
+                if block[0] == '*':
+                    # List items:
+                    for item in block[2:].split('\n* '):
+                        out += textwrap.fill(item,
+                                             width=width - 2,
+                                             initial_indent='* ',
+                                             subsequent_indent='  ') + '\n'
+                elif block[0] == ' ':
+                    # Indented literal block:
+                    out += block + '\n'
+                else:
+                    # Block of text:
+                    out += textwrap.fill(block, width=width) + '\n'
+                out += '\n'
             else:
-                # Block of text:
-                out += textwrap.fill(block, width=width) + '\n'
-            out += '\n'
+                pass
         return out[:-1]
 
 
